@@ -36,6 +36,7 @@ from .Models import (Alias, Attribute, Author, Book, BookAuthor, Category, File,
 RE_YEARS = re.compile(r'(.*)([12]\d\d\d)') # no years before 1000
 RE_CRLF = re.compile(r'[\n\r]+', flags=re.M)
 RE_PLACE = re.compile(r'^\[?([\w\. ]*):')
+RE_UPDATE = re.compile(r'\s*updated?:\s*', re.I)
 
 class DublinCoreObject(DublinCore.GutenbergDublinCore):
     """ Augment GutenbergDublinCore class. """
@@ -138,6 +139,10 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
             return (place, publisher, years)
 
+        def clean_credit(s):
+            # parse out updates
+            return RE_UPDATE.split(s)[0].strip()
+
         book = self.load_book(ebook)
         if not book:
             return
@@ -182,7 +187,7 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
             elif marc.code == '505':
                 self.contents = marc.text
             elif marc.code == '508':
-                self.credit = marc.text
+                self.credit = clean_credit(marc.text)
             elif marc.code == '904':
                 self.scan_urls = marc.text
             elif marc.code == '905':
@@ -318,12 +323,8 @@ class DublinCoreObject(DublinCore.GutenbergDublinCore):
 
         session = self.get_my_session()
         if self.book.updatemode != updatemode:
-            # updated files, mostly don't change metadata
-            info("ebook #%s already in database, marking update.", self.book.pk)
-            if datetime.date.today() - self.book.release_date > datetime.timedelta(days=14):
-                self.add_credit('Updated: ' + str(datetime.date.today()))
-                self.add_attribute(self.book, [self.credit], marc=508)
-                session.commit()
+            self.add_attribute(self.book, [self.credit], marc=508)
+            session.commit()
             return
 
         # either 0=0 for fresh book updatemode or 1=1 for re-editing old book
